@@ -1,18 +1,16 @@
+from connect.autogen import connect_util_Dictionary as Dictionary
 from connect.autogen import connect_util_Blob as Blob
 from connect.autogen import connect_util_Collection as Collection
 from connect.autogen import connect_util_DateTime as DateTime
-from connect.autogen import connect_util_Dictionary as Dictionary
-from connect.autogen import connect_util_Diff as Diff
 from connect.autogen import connect_util_ExcelWriter as ExcelWriter
 from connect.autogen import connect_util_Util as Util
 
 
 __all__ = [
+    'Dictionary',
     'Blob',
     'Collection',
     'DateTime',
-    'Dictionary',
-    'Diff',
     'ExcelWriter',
     'Util',
 ]
